@@ -21,9 +21,9 @@
 #include <dirent.h>
 #include <sys/types.h>
 #include <stdlib.h>
-#include <ntqstringlist.h>
+#include <tqstringlist.h>
 #include <tdelocale.h>
-#include <ntqregexp.h>
+#include <tqregexp.h>
 
 #include "sensor.h"
 #include "hdsensorslist.h"
