@@ -17,14 +17,14 @@
 
 #include "ksensorscfg.h"
 
-#include <ntqvariant.h>
-#include <ntqframe.h>
-#include <ntqlayout.h>
-#include <ntqlabel.h>
-#include <ntqtooltip.h>
-#include <ntqwhatsthis.h>
-#include <ntqimage.h>
-#include <ntqpixmap.h>
+#include <tqvariant.h>
+#include <tqframe.h>
+#include <tqlayout.h>
+#include <tqlabel.h>
+#include <tqtooltip.h>
+#include <tqwhatsthis.h>
+#include <tqimage.h>
+#include <tqpixmap.h>
 
 #include <kiconloader.h>
 #include <tdelocale.h>
