@@ -18,8 +18,8 @@
 #ifndef KSENSORSSPLASH_H
 #define KSENSORSSPLASH_H
 
-#include <ntqwidget.h>
-//#include <ntqwidget.h>
+#include <tqwidget.h>
+//#include <tqwidget.h>
 
 
 /**
@@ -27,7 +27,7 @@
   */
 
 class KSensorsSplash : public TQWidget  {
- Q_OBJECT
+ TQ_OBJECT
 public:
 
   KSensorsSplash(TQWidget *parent=0, const char *name=0 );
