@@ -16,7 +16,7 @@
  ***************************************************************************/
 
 
-#include <ntqpixmap.h>
+#include <tqpixmap.h>
 
 #include <kstddirs.h>
 #include <tdelocale.h>
