@@ -18,7 +18,7 @@
 
 #include <stdlib.h>
 
-#include <ntqstring.h>
+#include <tqstring.h>
 #include <tdeglobal.h>
 #include <kprocess.h>
 #include <kaudioplayer.h>
