@@ -15,10 +15,10 @@
  *                                                                         *
  ***************************************************************************/
 
-#include <ntqobject.h>
-#include <ntqobjectlist.h>
-#include <ntqpixmap.h>
-#include <ntqtimer.h>
+#include <tqobject.h>
+#include <tqobjectlist.h>
+#include <tqpixmap.h>
+#include <tqtimer.h>
 
 #include <kiconloader.h>
 #include <kstddirs.h>
